summaryrefslogtreecommitdiffstats
path: root/chrome/browser/autofill/form_structure.h
diff options
context:
space:
mode:
authorgeorgey@chromium.org <georgey@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-22 21:23:18 +0000
committergeorgey@chromium.org <georgey@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-22 21:23:18 +0000
commit427b7da73e9e9aa09dc9b899974fb24a1a3dcfe5 (patch)
tree493f5b87e12d5ab04b8d4c39f01c1193936ca5b3 /chrome/browser/autofill/form_structure.h
parente731a165a769e743af79f742d09a283b41d74ca1 (diff)
downloadchromium_src-427b7da73e9e9aa09dc9b899974fb24a1a3dcfe5.zip
chromium_src-427b7da73e9e9aa09dc9b899974fb24a1a3dcfe5.tar.gz
chromium_src-427b7da73e9e9aa09dc9b899974fb24a1a3dcfe5.tar.bz2
Integration with Toolbar autofill servers.
Still to do: 1. Update upload rates based on response 2. Differentiate autofilled/not uploads 3. Do not query if there is no items in autofill 4. Fix forms to correspond to the data queried by toolbar BUG=none TEST=Should request data from toolbar servers Review URL: http://codereview.chromium.org/1119004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@42260 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/autofill/form_structure.h')
-rw-r--r--chrome/browser/autofill/form_structure.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/chrome/browser/autofill/form_structure.h b/chrome/browser/autofill/form_structure.h
index 4376987..3802aed 100644
--- a/chrome/browser/autofill/form_structure.h
+++ b/chrome/browser/autofill/form_structure.h
@@ -36,8 +36,10 @@ class FormStructure {
public:
explicit FormStructure(const webkit_glue::FormFieldValues& values);
- // Encodes the XML upload request from this FormStructure.
- bool EncodeUploadRequest(bool auto_fill_used, std::string* encoded_xml) const;
+ // Encodes the XML query or upload request from this FormStructure.
+ // |query| - true means request is a query, upload otherwise.
+ bool EncodeUploadRequest(bool auto_fill_used, bool query,
+ std::string* encoded_xml) const;
// Runs several heuristics against the form fields to determine their possible
// types.